#ifndef WLR_CONFIG_H
#define WLR_CONFIG_H

#define WLR_HAS_SYSTEMD 1
#define WLR_HAS_ELOGIND 0

#define WLR_HAS_LIBSEAT 0

#define WLR_HAS_X11_BACKEND 1

#define WLR_HAS_XWAYLAND 1

#define WLR_HAS_XCB_ERRORS 1

#define WLR_HAS_XDG_FOREIGN 1

#endif
